
from setuptools import setup, find_packages

setup(
    name="html_opener_library",
    version="0.1.0",
    description="A library to open HTML files periodically in a browser.",
    author="Kriperovich",
    packages=find_packages(),
    install_requires=[],
    python_requires='>=3.6',
)
